// $Id$

/***************************************************************************
*   Copyright (C) 2004 by Thomas Fischer                                  *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <klocale.h>

#include <bibtexelement.h>

BibTeXElement::BibTeXElement( QObject *parent, const char *name )
        : QObject( parent, name )
{}


BibTeXElement::~BibTeXElement()
{}

QString BibTeXElement::elementTypeToString( const ElementType elementType )
{
    switch ( elementType )
    {
    case etString:
        return QString( "String" );
    case etComment:
        return QString( "Comment" );
    case etPreamble:
        return QString( "Preamble" );
    case etArticle:
        return QString( "Article" );
    case etBook:
        return QString( "Book" );
    case etBooklet:
        return QString( "Booklet" );
    case etCollection:
        return QString( "Collection" );
    case etConference:
        return QString( "Conference" );
    case etInBook:
        return QString( "InBook" );
    case etInCollection:
        return QString( "InCollection" );
    case etInProceedings:
        return QString( "InProceedings" );
    case etManual:
        return QString( "Manual" );
    case etMastersThesis:
        return QString( "MastersThesis" );
    case etMisc:
        return QString( "Misc" );
    case etPhDThesis:
        return QString( "PhDThesis" );
    case etProceedings:
        return QString( "Proceedings" );
    case etTechReport:
        return QString( "TechReport" );
    case etUnpublished:
        return QString( "Unpublished" );
    default:
        return QString( "Unknown" );
    }
}

QString BibTeXElement::elementTypeDescriptionI18N( const ElementType elementType, bool withShortcuts )
{
    QString result;

    switch ( elementType )
    {
    case etString:
        return result = i18n( "&String" );
    case etComment:
        return result = i18n( "&Comment" );
    case etPreamble:
        return result = i18n( "&Preamble" );
    case etArticle:
        return result = i18n( "&Article" );
    case etBook:
        return result = i18n( "&Book" );
    case etBooklet:
        return result = i18n( "Boo&klet" );
    case etCollection:
        return result = i18n( "Coll&ection" );
    case etConference:
        return result = i18n( "C&onference" );
    case etInBook:
        return result = i18n( "&In Book" );
    case etInCollection:
        return result = i18n( "I&n Collection" );
    case etInProceedings:
        return result = i18n( "In P&roceedings" );
    case etManual:
        return result = i18n( "&Manual" );
    case etMastersThesis:
        return result = i18n( "Master's T&hesis" );
    case etMisc:
        return result = i18n( "Misce&llaneous" );
    case etPhDThesis:
        return result = i18n( "Ph&D Thesis" );
    case etProceedings:
        return result = i18n( "Proceedin&gs" );
    case etTechReport:
        return result = i18n( "&Technical Report" );
    case etUnpublished:
        return result = i18n( "&Unpublished" );
    default:
        return result = i18n( "Unknown" );
    }

    if ( !withShortcuts )
        result.remove( '&' );

    return result;
}

BibTeXElement::ElementType BibTeXElement::elementTypeFromString( const QString &elementTypeString )
{
    if ( elementTypeString.compare( "article" ) == 0 )
        return etArticle;
    else if ( elementTypeString.compare( "book" ) == 0 )
        return etBook;
    else if ( elementTypeString.compare( "booklet" ) == 0 )
        return etBooklet;
    else if ( elementTypeString.compare( "collection" ) == 0 )
        return etCollection;
    else if ( elementTypeString.compare( "conference" ) == 0 )
        return etConference;
    else if ( elementTypeString.compare( "inbook" ) == 0 )
        return etInBook;
    else if ( elementTypeString.compare( "incollection" ) == 0 )
        return etInCollection;
    else if ( elementTypeString.compare( "inproceedings" ) == 0 )
        return etInProceedings;
    else if ( elementTypeString.compare( "manual" ) == 0 )
        return etManual;
    else if ( elementTypeString.compare( "mastersthesis" ) == 0 )
        return etMastersThesis;
    else if ( elementTypeString.compare( "misc" ) == 0 )
        return etMisc;
    else if ( elementTypeString.compare( "phdthesis" ) == 0 )
        return etPhDThesis;
    else if ( elementTypeString.compare( "proceedings" ) == 0 )
        return etProceedings;
    else if ( elementTypeString.compare( "techreport" ) == 0 )
        return etTechReport;
    else if ( elementTypeString.compare( "unpublished" ) == 0 )
        return etUnpublished;
    else
        return etUnknown;
}


#include "bibtexelement.moc"
